How to contribute
=================

Reporting bugs
--------------

Before reporting please:

- Double-check `the documentation
  <http://docs.translatehouse.org/projects/pootle/>`_.
- Make sure `the issue hasn't been already reported
  <https://github.com/translate/pootle/issues/>`_.


Write your bug report so that you ensure developers are fixing the bug rather
than spending time trying to understand it.  If we can't see it or replicate it,
likely we can't fix it.

Checklist:

#. Bug description is clear yet concise.
#. Clear instructions to reliably replicate the issue.
#. Screenshots rather than descriptions of screens.
#. Full traceback if one occurred.
#. Links to the actual issue.


Commits and Pull Requests
-------------------------

Before contributing any code, please:

- Do not write any code without consulting about it first, unless it is a
  trivial fix. Someone else can be already working on it.
- Think if any code is needed at all: `The Best Code is No Code At All
  <http://blog.codinghorror.com/the-best-code-is-no-code-at-all/>`_.


Keep the commit log as healthy as the code. It is one of the first places new
contributors will look at the project.

#. No more than one change per commit. There should be no changes in a commit
   which are unrelated to its message.
#. Every Pull Request should pass all tests on its own. Ideally each commit
   should too.
#. Follow `these conventions <http://chris.beams.io/posts/git-commit/>`_ when
   writing the commit message.


When filing a Pull Request, make sure it is rebased on top of most recent
`master`. If you need to modify it or amend it in some way, you should always
appropriately fixup the issues in git and force-push your changes to your fork.

Also see: `Github Help: Using Pull Requests
<https://help.github.com/articles/using-pull-requests/>`_


Translations
------------

Please `translate online <http://pootle.locamotion.org/projects/pootle/>`_.


Not sure how to contribute?
---------------------------

You can always get help in the `Pootle channel
<https://gitter.im/translate/pootle>`_.
